# sdkms/v1.TwoFactorAuthenticationApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**authorize_recovery_code**](TwoFactorAuthenticationApi.md#authorize_recovery_code) | **POST** /sys/v1/session/auth/2fa/recovery_code | Use a backup recovery code to complete authentication
[**authorize_u2_f**](TwoFactorAuthenticationApi.md#authorize_u2_f) | **POST** /sys/v1/session/auth/2fa/u2f | Use a U2F key to complete authentication
[**generate_recovery_codes**](TwoFactorAuthenticationApi.md#generate_recovery_codes) | **POST** /sys/v1/users/generate_recovery_code | Generate backup recovery codes for the current user
[**generate_u2_f_challenge**](TwoFactorAuthenticationApi.md#generate_u2_f_challenge) | **POST** /sys/v1/session/config_2fa/new_challenge | Generate a new challenge for registering a U2F devices
[**lock2_f**](TwoFactorAuthenticationApi.md#lock2_f) | **POST** /sys/v1/session/config_2fa/terminate | Lock two factor configuration


# **authorize_recovery_code**
> authorize_recovery_code()

Use a backup recovery code to complete authentication

Complete two factor authentication with a backup recovery code. The caller needs to provide a bearer token for the session in the request body. Each recovery code may only be used once, so users should update their two factor configuration after using this API. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.TwoFactorAuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Use a backup recovery code to complete authentication
    api_instance.authorize_recovery_code()
except ApiException as e:
    print("Exception when calling TwoFactorAuthenticationApi->authorize_recovery_code: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **authorize_u2_f**
> authorize_u2_f()

Use a U2F key to complete authentication

Complete two factor authentication with a U2F authentication token to authenticate to SDKMS. The response body contains a bearer authentication token which needs to be provided by subsequent calls for the duration of the session. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure HTTP basic authorization: basicAuth
configuration = sdkms/v1.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sdkms/v1.TwoFactorAuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Use a U2F key to complete authentication
    api_instance.authorize_u2_f()
except ApiException as e:
    print("Exception when calling TwoFactorAuthenticationApi->authorize_u2_f: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **generate_recovery_codes**
> RecoveryCodes generate_recovery_codes()

Generate backup recovery codes for the current user

Generate backup recovery codes that may be used to complete complete two factor authentication. The caller needs to provide a bearer token for the session in the request body. Two factor configuration must be unlocked to use this API. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.TwoFactorAuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Generate backup recovery codes for the current user
    api_response = api_instance.generate_recovery_codes()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling TwoFactorAuthenticationApi->generate_recovery_codes: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**RecoveryCodes**](RecoveryCodes.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **generate_u2_f_challenge**
> MfaChallenge generate_u2_f_challenge()

Generate a new challenge for registering a U2F devices

Generate a new challenge that may be used to register U2F devices. The caller needs to provide a bearer token for the session in the request body. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.TwoFactorAuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Generate a new challenge for registering a U2F devices
    api_response = api_instance.generate_u2_f_challenge()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling TwoFactorAuthenticationApi->generate_u2_f_challenge: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**MfaChallenge**](MfaChallenge.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **lock2_f**
> lock2_f()

Lock two factor configuration

Lock two factor configuration after completing two factor reconfiguration. The caller needs to provide a bearer token for the session in the request body. If this API is not called, two factor configuration will be locked automatically after ten minutes. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.TwoFactorAuthenticationApi(sdkms/v1.ApiClient(configuration))

try: 
    # Lock two factor configuration
    api_instance.lock2_f()
except ApiException as e:
    print("Exception when calling TwoFactorAuthenticationApi->lock2_f: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

